@@ -1,10 +1,11 @@
 """Web mercator XYZ tile utilities"""
 
 from collections import namedtuple
+from collections import Sequence
 import math
 
 
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 
 __all__ = [
     'Bbox', 'LngLat', 'LngLatBbox', 'Tile', 'bounding_tile', 'bounds',
@@ -314,6 +315,9 @@ def tiles(west, south, east, north, zooms, truncate=False):
         e = min(180.0, e)
         n = min(85.051129, n)
 
+        if not isinstance(zooms, Sequence):
+            zooms = [zooms]
+
         for z in zooms:
             ll = tile(w, s, z)
             ur = tile(e, n, z)
